// JuliaGidlet.java

import ch.aplu.gidlet.*;

public class JuliaGidlet extends Gidlet
{
  private int maxIterations = 100;
  private double maxNorm = 50;
  private double step = 0.01;
  private double range = 2;
  private MPanel p =
    new MPanel("Julia set", -range, range, -range, range);

  public void main()
  {
    p.rectangle(-range, -range, range, range);
    drawJulia();
  }

  private void drawJulia()
  {
    Complex c = new Complex(-0.5, -0.5);
    Complex z0 = new Complex(-range, -range);
    int it;

    while (z0.getImg() < range && !isExiting()) // outer loop in imag direction
    {
      z0 = new Complex(-range, z0.getImg() + step);
      while (z0.getReal() < range) // inner loop in real direction
      {
        z0 = Complex.add(z0, new Complex(step, 0));

        // Julia iteration
        Complex z = z0;
        it = 0;
        while (z.modulus() < maxNorm && it < maxIterations)
        {
          // z = z^2 + c
          Complex temp = Complex.multiply(z, z);
          z = Complex.add(temp, c);
          it++;
        }
        if (it < 4)
          putPixel(z0, GRAY);
        else
          if (it < 5)
            putPixel(z0, GREEN);
          else
            if (it < 8)
              putPixel(z0, RED);
            else
              if (it < 12)
                putPixel(z0, BLUE);
              else
                if (it < 100)
                  putPixel(z0, YELLOW);
                else
                  putPixel(z0, BLACK);
      }
    }
  }

  private void putPixel(Complex z, int color)
  {
    p.color(color);
    p.point(z.getReal(), z.getImg());
  }
}
