// RFCommBrowser.java

import java.util.*;
import javax.bluetooth.*;
import ch.aplu.gidlet.*;
import ch.aplu.bluetooth.*;

public class RFCommBrowser extends Gidlet
  implements BluetoothResponder
{
  private MConsole c = new MConsole(0, BLUE, WHITE, 1);
  private BluetoothFinder btf;

  public void main()
  {
    int uuid_RFCOMM = 0x0003;
    int[] uuids = {uuid_RFCOMM};
    c.println("Searching RFCOMM services...");
    btf = new BluetoothFinder(uuids, false, this);
  }

  public void notifyBluetoothDeviceSearch(Vector deviceTable)
  {
    // Vector elements: DeviceInfo {RemoteDevice, DeviceClass}
    c.println("Device report:");
    if (deviceTable.size() > 0)
    {
      for (int i = 0; i < deviceTable.size(); i++)
      {
        BtDeviceInfo di = (BtDeviceInfo)deviceTable.elementAt(i);
        RemoteDevice dev = di.getRemoteDevice();
        String deviceName = btf.getDeviceName(dev);
        DeviceClass dc = di.getDeviceClass();
        int majorDC = dc.getMajorDeviceClass();
        int minorDC = dc.getMinorDeviceClass();
        c.println("Device found. Name: " + deviceName);
        c.println("  Major Device Class: " + majorDC);
        c.println("  Minor Device Class: " + minorDC);
      }
      c.println("\nSearching services...");
    }
    else
      c.println("No devices found");
  }

  public void notifyBluetoothServiceSearch(Vector serviceTable)
  {
    // Vector elements: ServiceInfo {RemoteDevice, ServiceRecord}
    c.println("Service report:");
    if (serviceTable.size() > 0)
    {
      for (int i = 0; i < serviceTable.size(); i++)
      {
        BtServiceInfo si = (BtServiceInfo)serviceTable.elementAt(i);
        RemoteDevice dev = si.getRemoteDevice();
        ServiceRecord sr = si.getServiceRecord();

        // Show host name
        String deviceName = btf.getDeviceName(dev);
        c.println("\nServices of host: " + deviceName);

        // Show service name
        String serviceName;
        DataElement de = sr.getAttributeValue(0x0100);
        if (de != null)
          serviceName = (String)de.getValue();
        else
          serviceName = "not found";
        c.println("Service name: " + serviceName);

        // Show connection URL
        String serviceUrl = sr.getConnectionURL(0, false);
        c.println("Connection URL: " + serviceUrl);
      }
    }
    else
      c.println("No services found");
  }
}
