// TextArea.java

/*
  This software is part of the Gidlet framework.
  It is Open Source Free Software, so you may
    - run the code for any purpose
    - study how the code works and adapt it to your needs
    - integrate all or parts of the code in your own programs
    - redistribute copies of the code
    - improve the code and release your improvements to the public
  However the use of the code is entirely your responsibility.
*/

package ch.aplu.gidlet;

import javax.microedition.lcdui.*;
import java.util.*;

/**
 * Class to display an upscrolling number of text lines automatically wrapped
 * at word boundaries. If the word length exceeds the maximum number of characters
 * per line, the word is separated.
 */
public class TextArea extends StringItem
{
 private int nbLines;
 private int nbChars;

 private String[] lines;
 private int lineIndex = -1;

 /**
  * Creates an TextArea with given title, maximum number of lines,
  * and maximum number of characers per line.
  * @param label the first line of the StringItem used as title
  * @param nbLines the maximum number of lines before scroll up
  * @param nbChars the maximum number of characters per line
  */
 public TextArea(String label, int nbLines, int nbChars)
 {
   super(label, "\n");
   this.nbLines = nbLines;
   this.nbChars = nbChars;
   lines = new String[nbLines];
   for (int i = 0; i < nbLines; i++)
     lines[i] = "";
 }

 /**
  * Appends a new line at the bottom of existing lines.
  * @param text the line to append
  */
 public void append(String text)
 {
   // Strip non-printing chars (e.g. <cr>, <lf>)
   StringBuffer sb = new StringBuffer("");
   for (int i = 0; i < text.length(); i++)
   {
     char ch = text.charAt(i);
     if ((int)ch >= 32)
        sb.append(ch);
   }
   String s = sb.toString();
   if (s.equals(""))
     s = " ";  // Empty line

   Vector v = new Vector();
   int beginIndex = 0;

   // Split in as many lines as needed, wrapped at <space>
   boolean done = false;
   while (!done)
   {
     int endIndex = getEndIndex(s);
     if (endIndex < 0)  // End of process
     {
       endIndex = -endIndex;
       done = true;
     }
     String line = s.substring(beginIndex, endIndex);
     v.addElement(line);
     if (!done)
        s = s.substring(endIndex);
   }
   for (int i = 0; i < v.size(); i++)
     insertLine((String)v.elementAt(i));

   show();
 }

 private void show()
 {
   String out = "\n";
   for (int i = 0; i <= lineIndex; i++)
     out = out + lines[i];
   setText(out);
 }

 private void insertLine(String line)
 {
   lineIndex++;
   if (lineIndex == nbLines)
   {
     shift();
     lineIndex--;
   }
   lines[lineIndex] = line + "\n";
 }

 private void shift()
 /* Move all lines one position upward */
 {
   for (int i = 1; i < nbLines; i++)
     lines[i-1] = lines[i];
 }

 private int getEndIndex(String s)
 /*
   Search the end index:
    if length of string <= nbChars
      return negative to mark end of process (no need to wrap)
    else
      search for last space beginning at position line_length-1
        if found, return space position
        else return line_length (unable to wrap at word boundaries)
 */
 {
   if (s.length() <= nbChars)
     return -s.length();

   int endIndex = s.lastIndexOf(' ', nbChars - 1);
   if (endIndex == -1)
     endIndex = nbChars;
   return endIndex;
 }
}
